%define libname %mklibname Rmath

%dnl Don't mangle shebangs in %{_libdir}/R/bin
%define __brp_mangle_shebangs %{_bindir}/true

# (tpg) really not needed
# for private copy in /usr/lib/R/share/perl/Text/DelimMatch.pm
%global __provides_exclude KernSmooth.so|MASS.so|R_X11.so|class.so|cluster.so|foreign.so|grDevices.so|grid.so|internet.so|lapack.so|lattice.so|libRblas.so|libRlapack.so|methods.so|mgcv.so|nlme.so|nnet.so|rpart.so|spatial.so|splines.so|stats.so|survival.so|tcltk.so|tools.so|vfonts.so|perl\\\(R::.*\\\)
%global __requires_exclude libRblas.so|libRlapack.so|perl\\\(R::.*\\\)

%define _disable_ld_no_undefined 1

%bcond_without tcltk
%bcond_without java
%bcond_without system_tre

Summary:	A language for data analysis and graphics
Name:		R-base
Version:	4.5.0
Release:	%mkrel 2
License:	GPLv2+
Group:		Sciences/Mathematics
URL:		https://www.r-project.org
Source0:	https://cran.r-project.org/src/base/R-4/R-%{version}.tar.gz
Source1:	https://www.r-project.org/logo/Rlogo.png#/Rlogo-%{version}.png
Source2:	https://www.r-project.org/logo/Rlogo.svg#/Rlogo-%{version}.svg
Source3:	R.bash_completion
Patch0:		R-2.15.3-menu.patch
Patch11:	R-4.4.2-roman-tests.patch
BuildRequires:	bison
BuildRequires:	pkgconfig(blas)
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	cups-common
BuildRequires:	gcc
BuildRequires:	gcc-c++
BuildRequires:	gcc-gfortran
BuildRequires:	gcc-objc
BuildRequires:	gcc-objc++
BuildRequires:	gettext-devel
BuildRequires:	glibc-devel
BuildRequires:	gpm-devel
BuildRequires:	icu-devel
BuildRequires:	imagemagick
BuildRequires:	imake
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	lapack-devel
BuildRequires:	paper-utils
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(liblzma)
BuildRequires:	pkgconfig(libpcre2-8)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(pango)
%if %{with system_tre}
BuildRequires:	pkgconfig(tre)
%else
Provides:	bundled(tre) = 0.8.0
%endif
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(xt)
%ifnarch %arm aarch64
BuildRequires:	quadmath-devel
%endif
BuildRequires:	pkgconfig(readline)
BuildRequires:	texinfo
BuildRequires:	texinfo-tex
BuildRequires:	texlive
BuildRequires:	texlive-fontsextra
BuildRequires:	xdg-utils
BuildRequires:	zip
%if %{with java}
BuildRequires:	java-devel
%endif
%if %{with tcltk}
BuildRequires:	tcl
BuildRequires:	pkgconfig(tcl)
BuildRequires:	pkgconfig(tk)
Requires:	tcl
Requires:	tk
Requires:	x11-font-adobe-100dpi
%endif

Provides:	R = %{version}
Provides:	R-recommended = %{version}
Requires:	perl
Requires:	sed

# needed in order to test setlocale in make check
BuildRequires:  locales-en
Provides: R(methods) = %{version}
Provides: R(utils) = %{version}
Provides: R(base) = %{version}
Provides: R(class) = %{version}
Provides: R(tools) = %{version}
Provides: R-core = %{version}
# First 2 numbers of version separated by dot
Provides: R(ABI) = %(echo %{version}|cut -d. -f1,2)

%description
`GNU S' - A language and environment for statistical computing and
graphics. R is similar to the S system, which was developed at Bell
Laboratories by John Chambers et al. It provides a wide variety of
statistical and graphical techniques (linear and nonlinear modelling,
statistical tests, time series analysis, classification, clustering, ...).

R is designed as a true computer language with control-flow
constructions for iteration and alternation, and it allows users to
add additional functionality by defining new functions. For
computationally intensive tasks, C, C++ and Fortran code can be linked
and called at run time.

%package -n %{libname}
Summary:	Standalone math library from the R project
Group:		Development/Other

%description -n %{libname}
A standalone library of mathematical and statistical functions derived
from the R project.  This packages provides the shared libRmath library.

%package -n %{libname}-devel
Summary:	Standalone math library from the R project
Group:		Development/Other
Provides:	libRmath-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}

%description -n %{libname}-devel
A standalone library of mathematical and statistical functions derived
from the R project.  This packages provides the static libRmath library
and header files.

%prep
%autosetup -p1 -n R-%{version}

%build
export R_BROWSER="$(type -p xdg-open)"
export R_PDFVIEWER="$(type -p xdg-open)"
export R_PRINTCMD="lpr"
%if %{with java}
export JAVA_HOME="%{java_home}"
%endif
unset DISPLAY

# Turn off enable-lto.
# lto requires that the flags for static libraries be
# set specifically, and this causes link errors with CRAN
# packages.
#
# See bug #13528 for where this can fail

# the regression tests will fail with an external Lapack
# 3.9.0 unless it has this fix is put into the lapack.

# https://github.com/Reference-LAPACK/lapack/pull/390
# https://github.com/xianyi/OpenBLAS/pull/2442

%configure \
%if %{with tcltk}
	--with-tcltk \
	--with-tcl-config=%{_libdir}/tclConfig.sh \
	--with-tk-config=%{_libdir}/tkConfig.sh \
%else
	--without-tcltk \
%endif
	--with-cairo \
	--with-libpng \
	--with-jpeglib \
	--with-pcre2 \
	--with-system-tre=%{?with_system_tre:yes}%{?!with_system_tre:no} \
	--with-ICU \
	--with-readline \
	--disable-BLAS-shlib \
	--with-lapack \
	--with-blas \
	--enable-threads=pth \
	--enable-R-profiling \
	--enable-R-shlib \
	--disable-lto

%make_build

pushd src/nmath/standalone
%make_build
popd

%make_build pdf
%make_build info

# DON'T comment "make check" below! If R doesn't pass the 'check' test
# then it is probably badly compiled, or there are problems with
# the compiler.
#
%check
%ifarch armv7hl %{ix86}
TZ="Europe/Paris" LC_ALL=C make check || (find -name "*.fail" | xargs cat)
%else
TZ="Europe/Paris" LC_ALL=C make check || (find -name "*.fail" | xargs cat ; exit 1)
%endif

%install
# N.B. don't use %%makeinstall because it sets prefix= which breaks Rscript
# mga#1434
%make_install install-info

pushd src/nmath/standalone
%makeinstall \
    includedir=%{buildroot}%{_includedir} \
    libdir=%{buildroot}%{_libdir}
popd

mv doc/manual/*.pdf %{_builddir}/%{?buildsubdir} || :
# Add soft links (useful for TK gui)
for i in R-admin R-data refman R-exts R-FAQ R-intro R-lang; do
	ln -s %{_datadir}/doc/R-base/${i}.pdf %{buildroot}%{_libdir}/R/doc/manual/${i}.pdf
done

# Remove latex versions of help pages
#
rm -rf %{buildroot}%{_libdir}/R/library/*/latex/

# Get rid of buildroot in script
for i in %{buildroot}%{_libdir}/R/bin/R %{buildroot}%{_bindir}/R %{buildroot}%{_libdir}/pkgconfig/libR*.pc;
do
  sed -i "s|%{buildroot}||g" $i;
done

# Remove package indices. They are rebuilt by the postinstall script.
#
rm -f %{buildroot}%{_libdir}/R/doc/html/function.html
rm -f %{buildroot}%{_libdir}/R/doc/html/packages.html
rm -f %{buildroot}%{_libdir}/R/doc/html/search/index.txt

# Fix permissions
chmod 644 %{buildroot}%{_libdir}/R/library/MASS/scripts/*
chmod 755 %{buildroot}%{_libdir}/R/share/sh/echo.sh

%if %{with tcltk}
# .desktop
mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/mageia-%{name}.desktop <<EOF
[Desktop Entry]
Name=R
GenericName=GNU R language
GenericName[ru]=Язык GNU R
Comment=A language for statistical computing
Comment[ar]=لغة للحساب الإحصائي
Comment[bg]=Език за статистичеки изчисления
Comment[cs]=Jazyk pro statistické výpočty
Comment[cy]=Iaith cyfrifiadura ystadegol
Comment[da]=Et sprog for statistisk beregning
Comment[el]=Μια γλώσσα για στατιστικούς υπολογισμούς
Comment[es]=R - un lenguaje para la computación estadística
Comment[et]=Statistiliste arvutusmeetodite keel
Comment[eu]=Konputazio estatistikoarentzako hizkuntza
Comment[fi]=Ohjelmointikieli tilastojen laskentaan
Comment[fr]=Un langage pour les calculs statistiques
Comment[gl]=Unha linguaxe para o cálculo estatístico
Comment[he]=שפה לחישוב סטטיסטי
Comment[hu]=Nyelv statisztikai programozáshoz
Comment[is]=Forritunarmál til tölfræðireikninga
Comment[it]=R, un linguaggio per elaborazioni statistiche
Comment[ky]=R - статистикалык эсептөө тили
Comment[nb]=Et program for statistisk beregning
Comment[nl]=Een taal voor statistische berekeningen
Comment[nn]=Statistiske utrekningar og simuleringar
Comment[pl]=Język służący do obliczeń statystycznych
Comment[pt]=Uma linguagem para computação estatística
Comment[pt_BR]=Uma linguagem para cálculos estatísticos
Comment[ro]=Un limbaj pentru calcul statistic
Comment[ru]=R - язык статистических вычислений
Comment[sl]=Jezik za statistično računanje
Comment[sv]=Ett språk för statistisk databehandling
Comment[tr]=İstatiksel hesaplamalar için dil
Comment[uk]=Мова для статистичних розрахунків
Comment[zh_CN]=一种统计计算语言
Comment[zh_TW]=一種用於統計學計算的語言
Exec=%{_bindir}/R --gui=tk
Terminal=true
Type=Application
Icon=Rlogo
Categories=Science;Math;
EOF

# icons
for S in 16 22 24 32 48 64 96 128 192 256 512; do
  %__install -d -m755 %{buildroot}%{_iconsdir}/hicolor/$S\x$S/apps
  convert -scale $S\x$S %{SOURCE1} %{buildroot}%{_iconsdir}/hicolor/$S\x$S/apps/Rlogo.png
done
%__install -d -m755 %{buildroot}%{_iconsdir}/hicolor/scalable/apps
%__install -m644 %{SOURCE2} %{buildroot}%{_iconsdir}/hicolor/scalable/apps/Rlogo.svg
%endif

# remove unpackaged files
rm -f %{buildroot}%{_infodir}/dir{,.old*}

# remove private perl libraries
rm -rf %{buildroot}%{_libdir}/R/share/perl/File
rm -rf %{buildroot}%{_libdir}/R/share/perl/Text

# (tpg) add bash completion file
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d
cp %{SOURCE3} %{buildroot}%{_sysconfdir}/bash_completion.d/R-base


%files
%doc README VERSION
%doc R-admin.pdf R-data.pdf R-exts.pdf R-FAQ.pdf R-intro.pdf R-lang.pdf
%{_bindir}/R
%{_bindir}/Rscript
%{_libdir}/R/bin
%{_libdir}/R/doc
%{_libdir}/R/etc
%{_libdir}/R/include
%{_libdir}/R/lib
%{_libdir}/R/modules
%{_libdir}/R/share
%dir %{_libdir}/R/library
%{_libdir}/R/library/KernSmooth
%{_libdir}/R/library/MASS
%{_libdir}/R/library/Matrix
%{_libdir}/R/library/base
%{_libdir}/R/library/boot
%{_libdir}/R/library/class
%{_libdir}/R/library/cluster
%{_libdir}/R/library/codetools
%{_libdir}/R/library/compiler
%{_libdir}/R/library/datasets
%{_libdir}/R/library/foreign
%{_libdir}/R/library/grDevices
%{_libdir}/R/library/graphics
%{_libdir}/R/library/grid
%{_libdir}/R/library/lattice
%{_libdir}/R/library/methods
%{_libdir}/R/library/mgcv
%{_libdir}/R/library/nlme
%{_libdir}/R/library/nnet
%{_libdir}/R/library/parallel
%{_libdir}/R/library/rpart
%{_libdir}/R/library/spatial
%{_libdir}/R/library/splines
%{_libdir}/R/library/stats
%{_libdir}/R/library/stats4
%{_libdir}/R/library/survival
%{_libdir}/R/library/tcltk
%{_libdir}/R/library/tools
%{_libdir}/R/library/utils
%dir %{_libdir}/R/library/translations/
%{_libdir}/R/library/translations/DESCRIPTION
%lang(ar) %{_libdir}/R/library/translations/ar/
%lang(bn) %{_libdir}/R/library/translations/bn/
%lang(ca) %{_libdir}/R/library/translations/ca/
%lang(da) %{_libdir}/R/library/translations/da/
%lang(de) %{_libdir}/R/library/translations/de/
%lang(en) %{_libdir}/R/library/translations/en*/
%lang(es) %{_libdir}/R/library/translations/es/
%lang(fa) %{_libdir}/R/library/translations/fa/
%lang(fr) %{_libdir}/R/library/translations/fr/
%lang(hi) %{_libdir}/R/library/translations/hi/
%lang(hu) %{_libdir}/R/library/translations/hu/
%lang(id) %{_libdir}/R/library/translations/id/
%lang(it) %{_libdir}/R/library/translations/it/
%lang(ja) %{_libdir}/R/library/translations/ja/
%lang(ko) %{_libdir}/R/library/translations/ko/
%lang(lt) %{_libdir}/R/library/translations/lt/
%lang(ne) %{_libdir}/R/library/translations/ne/
%lang(nn) %{_libdir}/R/library/translations/nn/
%lang(pl) %{_libdir}/R/library/translations/pl/
%lang(pt_BR) %{_libdir}/R/library/translations/pt_BR/
%lang(ru) %{_libdir}/R/library/translations/ru/
%lang(sq) %{_libdir}/R/library/translations/sq/
%lang(tr) %{_libdir}/R/library/translations/tr/
%lang(ur) %{_libdir}/R/library/translations/ur/
%lang(zh_CN) %{_libdir}/R/library/translations/zh_CN/
%lang(zh_TW) %{_libdir}/R/library/translations/zh_TW/
%{_infodir}/*.info*
%{_libdir}/R/COPYING
%{_libdir}/R/SVN-REVISION
%{_libdir}/pkgconfig/libR.pc
%{_mandir}/*/*
%{_sysconfdir}/bash_completion.d/*
%if %{with tcltk}
%{_datadir}/applications/*.desktop
%_iconsdir/hicolor/*/apps/Rlogo.png
%_iconsdir/hicolor/scalable/apps/Rlogo.svg
%endif

%files -n %{libname}
%{_libdir}/libRmath.so

%files -n %{libname}-devel
%{_libdir}/libRmath.a
%{_includedir}/Rmath.h
%{_libdir}/pkgconfig/libRmath.pc


%changelog
* Tue Jul 08 2025 umeabot <umeabot> 4.5.0-2.mga10
+ Revision: 2251456
- Mageia 10 Mass Rebuild

* Sun Apr 13 2025 daviddavid <daviddavid> 4.5.0-1.mga10
+ Revision: 2175493
- new version: 4.5.0

* Wed Jan 15 2025 wally <wally> 4.4.2-3.mga10
+ Revision: 2139340
- update as.roman() patch and add more tests for checking its behavior

* Wed Jan 15 2025 wally <wally> 4.4.2-2.mga10
+ Revision: 2139288
- fix .roman2numeric regex to fix as.roman(IIIII) behavior

* Mon Jan 13 2025 wally <wally> 4.4.2-1.mga10
+ Revision: 2138700
- new version 4.4.2
- clean build flags

* Sun Jan 12 2025 wally <wally> 4.4.1-3.mga10
+ Revision: 2138636
- fix tests
- rebuild for icu 76.1
+ papoteur <papoteur>
- more generic formula for Provides R(ABI)

* Tue Aug 27 2024 papoteur <papoteur> 4.4.1-2.mga10
+ Revision: 2091863
- fix provides R(ABI) version

* Tue Aug 27 2024 papoteur <papoteur> 4.4.1-1.mga10
+ Revision: 2091631
- new version 4.4.1
- new version 4.3.1

* Wed Feb 28 2024 papoteur <papoteur> 4.3.2-1.mga10
+ Revision: 2044891
- new version 4.3.2
- new version 4.3.2

* Sat Oct 14 2023 daviddavid <daviddavid> 4.3.1-1.mga10
+ Revision: 1996711
- new version: 4.3.1
- rebuild for icu73
+ tv <tv>
- Rebuild for icu-73

* Sun Apr 16 2023 daviddavid <daviddavid> 4.1.3-6.mga9
+ Revision: 1953388
- remove no more needed old pcre-devel build dependency

* Sat Jan 07 2023 squidf <squidf> 4.1.3-5.mga9
+ Revision: 1931166
- Mass rebuild for icu 72.1

* Mon Dec 12 2022 ns80 <ns80> 4.1.3-4.mga9
+ Revision: 1921107
- rebuild for new libtiff

* Thu Aug 11 2022 joequant <joequant> 4.1.3-3.mga9
+ Revision: 1876872
- change R(ABI) to 4.1

* Sat Jun 18 2022 squidf <squidf> 4.1.3-2.mga9
+ Revision: 1864896
- rebuild for icu 71.1

* Fri Apr 22 2022 joequant <joequant> 4.1.3-1.mga9
+ Revision: 1852569
- update to 4.1.3

* Fri Apr 01 2022 umeabot <umeabot> 4.0.5-3.mga9
+ Revision: 1840025
- Mageia 9 Mass Rebuild

* Tue Aug 03 2021 luigiwalser <luigiwalser> 4.0.5-2.mga9
+ Revision: 1738968
- rebuild for icu

* Thu Apr 29 2021 kekepower <kekepower> 4.0.5-1.mga9
+ Revision: 1720432
- Update to version 4.0.5

* Mon Nov 30 2020 luigiwalser <luigiwalser> 4.0.3-4.mga8
+ Revision: 1650926
- rebuild for icu

* Wed Nov 18 2020 joequant <joequant> 4.0.3-3.mga8
+ Revision: 1647103
- set cflags to -fPIC

* Wed Nov 18 2020 joequant <joequant> 4.0.3-2.mga8
+ Revision: 1647054
- Add R(ABI) provides

* Wed Nov 18 2020 joequant <joequant> 4.0.3-1.mga8
+ Revision: 1647023
- fix pcre2-devel
- update to 4.0.3

* Sun Nov 01 2020 joequant <joequant> 3.6.3-9.mga8
+ Revision: 1641071
- rebuild

* Sun Nov 01 2020 joequant <joequant> 3.6.3-8.mga8
+ Revision: 1641070
- fix deps
- use packaged configure

* Sun Aug 30 2020 joequant <joequant> 3.6.3-7.mga8
+ Revision: 1619906
- fix java dep
+ ovitters <ovitters>
- remove install-info scriptlets, rely on filetrigger instead (mga#27107)

* Wed Jul 01 2020 wally <wally> 3.6.3-5.mga8
+ Revision: 1601062
- rebuild for icu 67.1

* Wed Apr 22 2020 joequant <joequant> 3.6.3-4.mga8
+ Revision: 1570661
- add provides for r library packages

* Sat Apr 04 2020 wally <wally> 3.6.3-3.mga8
+ Revision: 1564499
- rebuild for new icu 66.1

* Sat Apr 04 2020 kekepower <kekepower> 3.6.3-2.mga8
+ Revision: 1564356
- Bump rel
- Add patch to remove a test that fails on aarch64
- Update to version 3.6.3

* Wed Feb 19 2020 umeabot <umeabot> 3.5.3-5.mga8
+ Revision: 1542332
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 3.5.3-4.mga8
+ Revision: 1476006
- rebuild for readline

* Sat Oct 05 2019 daviddavid <daviddavid> 3.5.3-3.mga8
+ Revision: 1449469
- rebuild for new icu 65.1

* Tue Apr 02 2019 pterjan <pterjan> 3.5.3-2.mga7
+ Revision: 1385454
- Ignore test failure on armv7hl for now

* Tue Mar 26 2019 pterjan <pterjan> 3.5.3-1.mga7
+ Revision: 1380303
- Update to 3.5.3 (minor bugfix release)

* Sat Dec 29 2018 kekepower <kekepower> 3.5.2-1.mga7
+ Revision: 1346387
- Update to version 3.5.2

* Sat Dec 29 2018 luigiwalser <luigiwalser> 3.5.1-5.mga7
+ Revision: 1346115
- rebuild for icu

* Thu Oct 11 2018 wally <wally> 3.5.1-4.mga7
+ Revision: 1319572
- don't mangle shebangs when building the pkg

* Sun Sep 23 2018 umeabot <umeabot> 3.5.1-3.mga7
+ Revision: 1300786
- Mageia 7 Mass Rebuild

* Mon Aug 20 2018 tv <tv> 3.5.1-2.mga7
+ Revision: 1252968
- rebuild for new libicu

* Sat Aug 11 2018 kekepower <kekepower> 3.5.1-1.mga7
+ Revision: 1251006
- Update to version 3.5.1

* Wed Jun 27 2018 pterjan <pterjan> 3.5.0-2.mga7
+ Revision: 1240228
- Do not BuildRequire quadmath-devel on aarch64

* Sat Apr 28 2018 kekepower <kekepower> 3.5.0-1.mga7
+ Revision: 1223164
- Update to version 3.5.0
- Update logos

* Sat Mar 31 2018 kekepower <kekepower> 3.4.4-1.mga7
+ Revision: 1213733
- Update to version 3.4.4

* Mon Feb 26 2018 daviddavid <daviddavid> 3.4.3-2.mga7
+ Revision: 1205313
- remove no more needed BR libpth-devel

* Sat Jan 20 2018 kekepower <kekepower> 3.4.3-1.mga7
+ Revision: 1195211
- Update to version 3.4.3

* Fri Dec 29 2017 wally <wally> 3.4.2-2.mga7
+ Revision: 1187011
- rebuild for new icu

* Sun Oct 15 2017 joequant <joequant> 3.4.2-1.mga7
+ Revision: 1171920
- add locales-en for make check
- disable some tests that fail because lack of /etc/localtime
- upgrade to 3.4.2

* Sun Sep 10 2017 joequant <joequant> 3.3.3-3.mga7
+ Revision: 1152378
- rebuild with new stack

* Wed Mar 15 2017 mrambo3501 <mrambo3501> 3.3.3-2.mga6
+ Revision: 1092806
- Rebuild for icu-58.2

* Mon Mar 06 2017 lmenut <lmenut> 3.3.3-1.mga6
+ Revision: 1089146
- update to 3.3.3

* Fri Jan 06 2017 lmenut <lmenut> 3.3.2-2.mga6
+ Revision: 1080308
- add upstream patch from R-3-3-branch to handle zlib 1.2.10

* Thu Nov 24 2016 lmenut <lmenut> 3.3.2-1.mga6
+ Revision: 1070065
- update to 3.3.2

* Tue Jul 05 2016 lmenut <lmenut> 3.3.1-1.mga6
+ Revision: 1039027
- update to 3.3.1

* Sat May 14 2016 shlomif <shlomif> 3.3.0-2.mga6
+ Revision: 1015254
- Rebuild for the new UCI (new major)

* Wed May 11 2016 lmenut <lmenut> 3.3.0-1.mga6
+ Revision: 1012410
- update to 3.3.0
- new upstream R logo (flat design)

* Tue Apr 19 2016 daviddavid <daviddavid> 3.2.5-2.mga6
+ Revision: 1003586
- rebuild against file 5.25 fixed on arm

* Mon Apr 18 2016 lmenut <lmenut> 3.2.5-1.mga6
+ Revision: 1003539
- Update to 3.2.5

* Sat Mar 26 2016 pterjan <pterjan> 3.2.4-3.mga6
+ Revision: 995677
- And one more slow test...
- Another test too slow on arm...

* Sat Mar 26 2016 pterjan <pterjan> 3.2.4-2.mga6
+ Revision: 995635
- Do not fail when a test taking 2s on arm takes more than 0.5s

* Mon Mar 21 2016 lmenut <lmenut> 3.2.4-1.mga6
+ Revision: 993825
- Update to 3.2.4-revised

* Fri Jan 01 2016 luigiwalser <luigiwalser> 3.2.3-2.mga6
+ Revision: 917815
- rebuild for icu

* Sun Dec 20 2015 lmenut <lmenut> 3.2.3-1.mga6
+ Revision: 912752
- Update to 3.2.3

* Sat Dec 05 2015 pterjan <pterjan> 3.2.2-1.mga6
+ Revision: 908378
- Enable java on arm
- Update to 3.2.2

* Sat Nov 28 2015 neoclust <neoclust> 3.2.1-5.mga6
+ Revision: 906538
- Rebuild for ARM

* Thu Nov 05 2015 pterjan <pterjan> 3.2.1-4.mga6
+ Revision: 897888
- Do not buildrequire libquadmath on arm

* Sun Oct 04 2015 daviddavid <daviddavid> 3.2.1-3.mga6
+ Revision: 886069
- rebuild for new tcl/tk 8.6.4
+ alexl <alexl>
- add GenericName

* Sat Jul 25 2015 cjw <cjw> 3.2.1-2.mga6
+ Revision: 857261
- rebuild for icu 55

* Sat Jul 18 2015 lmenut <lmenut> 3.2.1-1.mga6
+ Revision: 855161
- Update to 3.2.1
- use pkgconfig for BuildRequires
- sort BuildRequires

* Thu Nov 27 2014 alexl <alexl> 3.1.2-2.mga5
+ Revision: 799491
- translated desktop file

* Sun Nov 09 2014 lmenut <lmenut> 3.1.2-1.mga5
+ Revision: 796156
- update to 3.1.2
- use system tre
- fix translations packaging
- allow build without tclck using --without-tcltk

* Wed Oct 15 2014 umeabot <umeabot> 3.1.1-4.mga5
+ Revision: 747185
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.1.1-3.mga5
+ Revision: 687011
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 3.1.1-2.mga5
+ Revision: 677648
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

* Sun Aug 31 2014 lmenut <lmenut> 3.1.1-1.mga5
+ Revision: 670207
- Update to 3.1.1

* Tue Jun 17 2014 joequant <joequant> 3.0.3-4.mga5
+ Revision: 637733
- revert 637698 pending changes

* Tue Jun 17 2014 joequant <joequant> 3.0.3-3.mga5
+ Revision: 637698
- change dependencies.  Remove tk/tcl dependency.  Use system tre

* Mon Jun 16 2014 joequant <joequant> 3.0.3-2.mga5
+ Revision: 637578
- turn off LTO.  Problems with gcc 4.9.  See #13528

* Sat Apr 12 2014 joequant <joequant> 3.0.3-1.mga5
+ Revision: 613591
- upgrade to 3.0.3

* Tue Oct 22 2013 umeabot <umeabot> 3.0.2-2.mga4
+ Revision: 542031
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 lmenut <lmenut> 3.0.2-1.mga4
+ Revision: 496747
- Update to 3.0.2
  + remove obsoletes patches
  + fix file list
- update java buildrequires
- build fullrefman.pdf with inconsolata

* Fri Sep 27 2013 fwang <fwang> 2.15.3-4.mga4
+ Revision: 487512
- add fedora patch to build with texinfo 5
- rebuild for icu 52

* Tue Jun 04 2013 fwang <fwang> 2.15.3-3.mga4
+ Revision: 437006
- rebuild for new libpng

* Sun May 26 2013 fwang <fwang> 2.15.3-2.mga4
+ Revision: 428038
- rebuild for icu

* Sat Mar 02 2013 lmenut <lmenut> 2.15.3-1.mga3
+ Revision: 401111
- Update to 2.15.3
  + rediff patch0
  + build refman.pdf without inconsolata

* Mon Jan 14 2013 umeabot <umeabot> 2.15.2-3.mga3
+ Revision: 381114
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 fwang <fwang> 2.15.2-2.mga3
+ Revision: 323688
- rebuild for new pcre

* Wed Nov 21 2012 lmenut <lmenut> 2.15.2-1.mga3
+ Revision: 320394
- update to 2.15.2

* Fri Nov 09 2012 fwang <fwang> 2.15.1-3.mga3
+ Revision: 316670
- rebuild for updated icu

* Tue Nov 06 2012 fwang <fwang> 2.15.1-2.mga3
+ Revision: 314784
- rebuild for new icu

* Sun Aug 26 2012 lmenut <lmenut> 2.15.1-1.mga3
+ Revision: 284221
- update to 2.15.1
- add BuildRequires texinfo-tex

* Tue May 29 2012 fwang <fwang> 2.14.2-3.mga3
+ Revision: 249515
- rebuild for new icu

* Wed Feb 29 2012 lmenut <lmenut> 2.14.2-2.mga2
+ Revision: 216234
- update to 2.14.2
- clean spec

* Fri Dec 23 2011 fwang <fwang> 2.14.1-2.mga2
+ Revision: 186474
- rebuild for new libtiff

* Thu Dec 22 2011 lmenut <lmenut> 2.14.1-1.mga2
+ Revision: 185950
- update to 2.14.1

* Wed Dec 21 2011 lmenut <lmenut> 2.14.0-1.mga2
+ Revision: 185416
- update to 2.14.0
- fix BuildRequires:
  + add quadmath-devel
  + replace tetex-latex by texlive
  + add texlive-fontsextra (inconsolata.sty needed)

* Mon Oct 24 2011 fwang <fwang> 2.13.2-1.mga2
+ Revision: 157613
- fix build
- new version 2.13.2
- build with system pcre

* Fri Sep 30 2011 fwang <fwang> 2.13.1-2.mga2
+ Revision: 150404
- bump rel
- tighten br

* Sat Sep 24 2011 lmenut <lmenut> 2.13.1-1.mga2
+ Revision: 147547
- build with internal pcre for now
+ fwang <fwang>
- new version 2.13.1

* Sat Jul 02 2011 fwang <fwang> 2.13.0-4.mga2
+ Revision: 117330
- rebuild for new tcl

* Tue Jun 28 2011 ahmad <ahmad> 2.13.0-3.mga2
+ Revision: 114998
- Don't use %%makeinstall because it sets prefix= which breaks Rscript (mga#1434)

* Mon Jun 20 2011 fwang <fwang> 2.13.0-2.mga2
+ Revision: 110319
- rebuild for new icu

* Sun Apr 17 2011 lmenut <lmenut> 2.13.0-1.mga1
+ Revision: 87267
- update to 2.13.0
- re-enable check
- disable only BLAS test
- clean post and preun scripts

* Sun Jan 23 2011 ahmad <ahmad> 2.12.0-4.mga1
+ Revision: 33474
- drop old/unneeded scriptlets
- rename .desktop file
- imported package R-base


* Sat Nov 27 2010 Funda Wang <fwang@mandriva.org> 2.12.0-3mdv2011.0
+ Revision: 601641
- rebuild for liblzma

* Mon Nov 08 2010 Funda Wang <fwang@mandriva.org> 2.12.0-2mdv2011.0
+ Revision: 594963
- bump rel
- try to export libR at least

* Sat Nov 06 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 2.12.0-1mdv2011.0
+ Revision: 594193
- disable check on all archs
- run checks only on ix86 arch
- update to new version 2.12.0
- add buildrequires on paper-utils

* Thu Apr 22 2010 Frederik Himpe <fhimpe@mandriva.org> 2.11.0-1mdv2010.1
+ Revision: 537985
- update to new version 2.11.0

* Sun Mar 21 2010 Funda Wang <fwang@mandriva.org> 2.10.1-4mdv2010.1
+ Revision: 526042
- rebuild for new icu

* Sun Jan 10 2010 Oden Eriksson <oeriksson@mandriva.com> 2.10.1-3mdv2010.1
+ Revision: 488740
- rebuilt against libjpeg v8

  + Giuseppe Ghibò <ghibo@mandriva.com>
    - Fix path for PDF manuals (needed by Tk gui).
    - Add graphics (Patch5) demo to list of available demos in Tk Gui menu.
    - make post script of cat of CONTENTS into index.txt more robust.

* Tue Dec 15 2009 Frederik Himpe <fhimpe@mandriva.org> 2.10.1-1mdv2010.1
+ Revision: 479120
- Update to new version 2.10.1
- Remove string format patch: not needed anymore

* Sun Nov 08 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 2.10.0-1mdv2010.1
+ Revision: 463065
- add buildrequires on icu-devel and lzma-devel
- update to new version 2.10.0

  + Olivier Blin <oblin@mandriva.com>
    - disable java on mips & arm (from Arnaud Patard)

* Mon Aug 24 2009 Frederik Himpe <fhimpe@mandriva.org> 2.9.2-1mdv2010.0
+ Revision: 420514
- Update to new version 2.9.2
- Update string format patch

* Sat Aug 15 2009 Oden Eriksson <oeriksson@mandriva.com> 2.9.0-2mdv2010.0
+ Revision: 416647
- rebuilt against libjpeg v7

* Sun Jun 14 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 2.9.0-1mdv2010.0
+ Revision: 385948
- update to new version 2.9.0

* Wed Mar 18 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 2.8.1-6mdv2009.1
+ Revision: 357464
- disable for now checks for ix86, because they fails only in iurt
- rebuild
- rebuild
- define _disable_ld_no_undefined 1, because i have no idea how to fix Makefile compressed into tarball, R kernel modules
- patch 1 is not needed anymore
- update to new version 2.8.1
- export compiles flags by using %%setup_compile_flags macro

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - add pth-devel and glibc-static-devel to build dependencies
    - rebuild for latest tk libs

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild for new libreadline

* Fri Oct 31 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.8.0-1mdv2009.1
+ Revision: 299061
- disable patch 3 for now
- disable patch 1 for now
- update to new version 2.8.0

* Wed Sep 17 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.7.2-2mdv2009.0
+ Revision: 285483
- Patch3: security fix for CVE-2008-3931

* Tue Aug 26 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.7.2-1mdv2009.0
+ Revision: 276262
- update to new version 2.7.2

* Thu Aug 07 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.7.1-2mdv2009.0
+ Revision: 266675
- disable -ffast-math flag as it breaks tests
- add conditionals for mdv 200900
- Patch1: fix detection of bzip2 version
- Patch2: fix underlinking (work in progress)
- use %%{_prefix} instead of hardcoded /usr/local
- compile against system wide blas and lapack (disabled --enable-BLAS-shlib)
- use pth threads
- use _disable_ld_no_undefined to fix build
- add missing buildrequires on imake, gcc-objc, gcc-objc++ and gettext-devel
- require x11-font-adobe-100dpi
- add buildrequires on zip
- do not set R_LIBS variable (#37781)
- add requires on x11-font-adobe-75dpi, as it was pointed on cooker ML
- try to build with enabled -ffast-math
- update to new version 2.7.1

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas
    - fix typo calling %%clean_icon_cache in %%postun
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu Apr 24 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.7.0-4mdv2009.0
+ Revision: 197249
- add buildrequires on pango, cairo and tiff

* Thu Apr 24 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.7.0-3mdv2009.0
+ Revision: 197243
- new version

* Mon Feb 11 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.6.2-3mdv2008.1
+ Revision: 165448
- revert my last commit (lapack & blas)
- use system blas and lapack libraries
- add bash completion file

* Mon Feb 11 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.6.2-2mdv2008.1
+ Revision: 165176
- use xdg-open instead of hardcoding pdfviewer and web browser

* Sun Feb 10 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.6.2-1mdv2008.1
+ Revision: 164979
- enable java support
- add missing build requires on bison and paper-utils
- export FCFLAGS and OBJCFLAGS
- use xpdf as a default pdf viewer
- do not compile with -ffast-math, as it breaks checks
- new version 2.6.2

* Wed Dec 19 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 2.6.1-4mdv2008.1
+ Revision: 133819
- fix exceptions for package requires

* Sun Dec 16 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 2.6.1-3mdv2008.1
+ Revision: 120664
- add requires exceptions on perl(R::*)
- new license policy
- do not package COPYING file
- add missing scriplets

* Wed Dec 12 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.6.1-2mdv2008.1
+ Revision: 118467
- don't provide private perl libraries
  don't even ship private copies of standard ones

* Tue Nov 27 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 2.6.1-1mdv2008.1
+ Revision: 113286
- new version

* Tue Oct 09 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 2.6.0-1mdv2008.1
+ Revision: 96121
- new version
- requires tk

* Fri Sep 07 2007 Anssi Hannula <anssi@mandriva.org> 2.5.1-3mdv2008.0
+ Revision: 82069
- buildrequires tcl-devel
- rebuild for new soname of tcl

* Thu Sep 06 2007 Adam Williamson <awilliamson@mandriva.org> 2.5.1-2mdv2008.0
+ Revision: 81307
- menu entry fix for #33216

* Tue Jul 03 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 2.5.1-1mdv2008.0
+ Revision: 47695
- drop patch 1
- new version

* Sat Jun 16 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 2.5.0-7mdv2008.0
+ Revision: 40396
- blacklist self-requires on libraries

* Sat Jun 16 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 2.5.0-6mdv2008.0
+ Revision: 40300
- really remove unneeded requires
- blacklist libraries as a provides

* Fri Jun 15 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 2.5.0-5mdv2008.0
+ Revision: 39940
- blacklist lapack.so from provides
- fix bug #31177
- evince is now default pdf viewer
- fix file list
- get rid of ld.so.conf.d stuff

* Sat May 05 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 2.5.0-4mdv2008.0
+ Revision: 23202
- R doesn't set its own library path, now it does
- correct requires on R and libRmath
- drop unused directory

* Thu May 03 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 2.5.0-3mdv2008.0
+ Revision: 21963
- enable libRmath compiling
- add reworked P1 from Fedora
- added some stuff - hope rkward will work

* Mon Apr 30 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 2.5.0-2mdv2008.0
+ Revision: 19462
- remove buildrequires on liblapack-devel
- drop P0 (seems to be not needed)
- revoke dead configure options and add new ones
- fix buildrequires
- drop old menu style

* Thu Apr 26 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 2.5.0-1mdv2008.0
+ Revision: 18415
- new version
- own missing files


* Sun Feb 18 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.4.1-2mdv2007.0
+ Revision: 122253
- xdg menus.

* Fri Feb 09 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.4.1-1mdv2007.1
+ Revision: 118653
- Release 2.4.1.

* Wed Nov 15 2006 Olivier Blin <oblin@mandriva.com> 2.4.0-1mdv2007.1
+ Revision: 84511
- 2.4.0
- Import R-base

* Mon Jun 19 2006 Stefan van der Eijk <stefan@eijk.nu.lurtspam> 2.3.1-1mdv2007.0
- rebuild for png

* Sat Jun 03 2006 Jerome Soyer <saispo@mandriva.org> 2.3.1-1mdv2007.0
- New release 2.3.1

* Sat May 20 2006 Jerome Soyer <saispo@mandriva.org> 2.2.1-2mdk
- Rebuild for the new glibc

* Fri Mar 10 2006 Giuseppe Ghibò <ghibo@mandriva.com> 2.2.1-1mdk
- Release 2.2.1.

* Sun Jan 01 2006 Oden Eriksson <oeriksson@mandriva.com> 2.2.0-5mdk
- rebuilt against soname aware deps

* Sat Dec 10 2005 Giuseppe Ghibò <ghibo@mandriva.com> 2.2.0-4mdk
- Don't use parallel build for %%make check
- Added cups-common to BuildRequires.

* Wed Dec 07 2005 Giuseppe Ghibò <ghibo@mandriva.org> 2.2.0-3mdk
- fix bug #19905.

* Sun Nov 27 2005 Michael Scherer <misc@mandriva.org> 2.2.0-2mdk
- do not provides perl(Text::DelimMatch)

* Thu Oct 20 2005 Giuseppe Ghibò <ghibo@mandriva.com> 2.2.0-1mdk
- Release: 2.2.0.

* Fri Aug 05 2005 Nicolas Lécureuil <neoclust@mandriva.org> 2.1.1-2mdk
- Fix BuildRequires

* Thu Aug 04 2005 Giuseppe Ghibò <ghibo@mandriva.com> 2.1.1-1mdk
- Release: 2.1.1.

* Fri Jun 17 2005 Couriousous <couriousous@mandriva.org> 2.1.0-2mdk
- Better fix for gcc4 bug
- Patch to allow R starting from desktop menu

* Sun May 08 2005 Giuseppe Ghibò <ghibo@mandriva.com> 2.1.0-1mdk
- Merged fixes from Couriousous <couriousous@mandriva.org>:
  - Release: 2.1.0.
  - Enable shared lib.
  - gnome gui is no more provided, use tk one in the menu.
  - Enable Large file support ( > 2Go ).
- lowered optimization from -O2 to -O1 due to gcc/gfortran bugs.
- fixed gcc-g77 BuildRequires.

* Sun Apr 17 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 2.0.1-5mdk
- Replaced libblas3-devel with libblas-devel in BuildConflicts
  (for X86_64).

* Wed Mar 23 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 2.0.1-4mdk
- Added Patch1 for supporting www-browser.

* Sat Jan 22 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.0.1-3mdk
- rebuild for new readline
- wipe out buildroot at the beginning of %%install
- cosmetics

* Thu Dec 16 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 2.0.1-2mdk
- Added libgnome-devel, libglade-devel to BuildRequires.

* Sun Dec 05 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 2.0.1-1mdk
- Release 2.0.1.
- Removed Patch1 (RestoreAction), merged upstream.

* Sat Nov 13 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 2.0.0-1mdk
- Release 2.0.0.
- Removed Patch1, merged upstream.
- Added Patch1 (RestoreAction) for fixing undefined (RestoreAction) in 
  R_gnome.so.

* Tue Oct 05 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 1.9.1-3mdk
- Added --gui=gnome to menu entry.
- Added Patch1 to allow R starting from desktop menu.

* Tue Aug 17 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 1.9.1-2mdk
- Rebuild with new menu

* Tue Jul 20 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 1.9.1-1mdk
- Release 1.9.1.
- Removed Patch1.

